<?php

namespace Apps\Calendar\Widget\CalendarEventForm;

use Core\Control\Form\Form;
use Core\View\View;
use Core\View\ElementView;

class CalendarEventForm extends Form {

    /**
     * Constructeur
     */
    function __construct($core = "", $data = "") {
        $this->Core = $core;
        $this->Data = $data;

        $this->Init($data);
    }

    /**
     * Initialisation 
     */
    function Init($data) {
        $this->form = new Form("CalendarEventFormForm", $data);

        $this->form->SetView(__DIR__ . "/View/index.tpl", $this->Core);
        $this->form->SetAction("/View/index.tpl");

        $this->form->Add(array("Type" => "Hidden",
            "Id" => "Id",
        ));
        
        $this->form->Add(array("Type" => "TextBox",
            "Id" => "Name",
            "Validators" => ["Required"]
        ));
        
        $this->form->Add(array("Type" => "TextArea",
            "Id" => "Description",
            "Validators" => ["Required"]
        ));

        $this->form->Add(array("Type" => "DateBox",
            "Id" => "DateStart",
            "Validators" => ["Required"]
        ));

        $this->form->Add(array("Type" => "DateTimeBox",
            "Id" => "HourStart",
        ));
        
        $this->form->Add(array("Type" => "DateBox",
            "Id" => "DateEnd",
        ));

        $this->form->Add(array("Type" => "DateTimeBox",
            "Id" => "HourEnd",
        ));
        
        $this->form->Add(array("Type" => "TextArea",
            "Id" => "Address",
        ));

        $this->form->Add(array("Type" => "NumericBox",
        "Id" => "NumberPlace",
        ));

        $this->form->Add(array("Type" => "Button",
            "Id" => "btnSaveEvent",
            "Value" => $this->Core->GetCode("Calendar.SaveEvent"),
            "CssClass" => "btn btn-primary"
        ));
    }

    /*     * *
     * Render the html form
     */

    function Render() {
        return $this->form->Render();
    }

    /*     * *
     * Validate the data
     */

    function Validate($data = "") {
        $errors = $this->form->Validate($this->Data);

        return $errors;
    }

    /*     * *
     * Load control with the entity
     */

    function Load($entity) {
        $this->form->Load($entity);
    }

    /*     * *
     * Populate the entity with the form Data
     */

    function Populate($entity) {
        
    }

    /*     * *
     * Error message
     */

    function Error() {
        $errors[] = $this->form->errors;

        return json_encode(array("statut" => "Error", "message" => $errors));
    }

}
